@@ -47,21 +47,30 @@
 		goto handler;												\
 	}
 
-//	-----------------------------------------------------------------
-#if 0
-#ifdef DEBUGLOGGING
-#define debugIOLog( message... ) \
-	do {IOLog( message ); IOSleep(20);} while (0)
-#else
-#define debugIOLog( message... ) ;
-#endif
-#endif
+//  -----------------------------------------------------------------
+//
+// System logging
+//
+//#define sleepTime 20
+#define sleepTime 0
 
 #ifdef DEBUGLOGGING
 #define debugIOLog( message... ) \
-	do {USBLog( DEBUG_LEVEL_DEVELOPMENT, message );} while (0)
+        do {IOLog( #message "\n", message ); IOSleep(sleepTime);} while (0)
 #else
 #define debugIOLog( message... ) ;
 #endif
 
+//
+// USB Prober logging
+//
+#if 0
+    #ifdef DEBUGLOGGING
+    #define debugIOLog( message... ) \
+            do {USBLog( DEBUG_LEVEL_DEVELOPMENT, message );} while (0)
+    #else
+    #define debugIOLog( message... ) ;
+    #endif
+#endif
+
 #endif /* _APPLEUSBAUDIOCOMMON_H */
