@@ -128,11 +128,6 @@ protected:
 	IOMemoryDescriptor *				neededSampleRateDescriptor;
 //	IOVirtualRange						theWrapRanges[2];
 	IONotifier *						streamNotifier;
-	OSObject *							interfaceVendor;
-	OSObject *							interfaceProduct;
-	OSObject *							deviceReleaseNumber;
-	OSObject *							configurationValue;
-	OSObject *							interfaceNumber;
 	void *								readBuffer;
 	void *								theStartBuffer;
 	UInt32 *							aveSampleRateBuf;		// only needs to be 3 bytes for the 10.14 value
@@ -160,7 +155,7 @@ protected:
 	UInt32								fractionalSamplesRemaining;
 	UInt16								samplesThisFrame;
 	UInt8								ourInterfaceNumber;
-	UInt8								alternateInterfaceID;
+	UInt8								alternateSettingID;
 	UInt8								refreshInterval;
 	UInt8								framesUntilRefresh;
 	UInt8								direction;
